﻿using System.Windows;
using Infragistics.Controls.Grids;
using Infragistics.Controls.Grids.Primitives;
using System.Collections;
using System.Windows.Controls;

namespace CustomXamGrid
{
    public class XamGridPerso : XamGrid
    {

        /// <summary>
        /// On remplace le ActiveItem de la classe mère : lier à ActiveItemProperty
        /// </summary>
        public new object FontSize
        {
            get
            {
                return (object)GetValue(FontSizeProperty);
            }
            set
            {
                SetValue(FontSizeProperty, value);
            }
        }

        /// <summary>
        /// On remplace le ActiveItemProperty de la classe mère (propriété de dépendance utilisable dans le xaml)
        /// </summary>
        public new static DependencyProperty FontSizeProperty =
            DependencyProperty.Register("FontSize", typeof(object), typeof(XamGridPerso), new PropertyMetadata(FontSizeChangedLocal));

        /// <summary>
        /// Executé à chaque fois que ActiveItem change (changement de l'élément sélectionné dans la XamGrid)
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private static void FontSizeChangedLocal(DependencyObject sender, DependencyPropertyChangedEventArgs e)
        {

           double taillePolice = double.Parse(e.NewValue.ToString());
           MajTaillePoliceXamgrid((XamGridPerso)sender, taillePolice);
        }
        
        public static void MajTaillePoliceXamgrid(XamGridPerso grille, double taillePolice)
        {
            Style style;
            Style headerCellControlStyle = new Style(typeof(HeaderCellControl));
            Style cellControlStyle = new Style(typeof(CellControl));

            StackPanel stackPanel = grille.Parent as StackPanel;
            Grid grid = stackPanel.Parent as Grid;
            foreach (var resource in grid.Resources)
            {
                DictionaryEntry dictionaryEntry = (DictionaryEntry)resource;
                Style tempStyle = dictionaryEntry.Value as Style;
                if (tempStyle != null)
                {
                    if (dictionaryEntry.Key.ToString() == "Infragistics.Controls.Grids.Primitives.HeaderCellControl")
                    {
                        headerCellControlStyle = tempStyle.Clone();
                    }
                    if (dictionaryEntry.Key.ToString() == "Infragistics.Controls.Grids.CellControl")
                    {
                        cellControlStyle = tempStyle.Clone();
                    }
                }
            }

            // Traiter les entêtes simples de colonne
            style = headerCellControlStyle;
            style.BasedOn = grille.HeaderStyle;
            style.Setters.Add(new Setter(HeaderCellControl.FontSizeProperty, taillePolice));
            grille.HeaderStyle = style;

            // Traiter les regroupements de colonnes
            foreach (object uneColonne in grille.Columns)
            {
                if (uneColonne.GetType() == typeof(GroupColumn))
                {
                    style = new Style(typeof(HeaderCellControl));
                    style.BasedOn = ((GroupColumn)uneColonne).HeaderStyle;
                    style.Setters.Add(new Setter(HeaderCellControl.FontSizeProperty, taillePolice));
                    ((GroupColumn)uneColonne).HeaderStyle = style;
                }
            }

            // Traiter les cellules
            style = cellControlStyle;
            style.BasedOn = grille.CellStyle;
            style.Setters.Add(new Setter(CellControl.FontSizeProperty, taillePolice));
            grille.CellStyle = style;

            // Traiter les lignes de regroupement de lignes
            style = new Style(typeof(GroupByCellControl));
            style.BasedOn = grille.GroupBySettings.GroupByRowStyle;
            style.Setters.Add(new Setter(GroupByCellControl.FontSizeProperty, taillePolice));
            grille.GroupBySettings.GroupByRowStyle = style;


            // Traiter la zone de regroupement
            style = new Style(typeof(GroupByAreaCellControl));
            style.BasedOn = grille.GroupBySettings.GroupByAreaStyle;
            style.Setters.Add(new Setter(GroupByAreaCellControl.FontSizeProperty, taillePolice));
            grille.GroupBySettings.GroupByAreaStyle = style;

            // Traiter es groupes à l'intérieur de la zone de regroupement
            style = new Style(typeof(GroupByHeaderCellControl));
            style.BasedOn = grille.GroupBySettings.GroupByHeaderStyle;
            style.Setters.Add(new Setter(GroupByHeaderCellControl.FontSizeProperty, taillePolice));
            grille.GroupBySettings.GroupByHeaderStyle = style;

        }

    }
}
